.. _skyline-installation-guide:

=====================================
Skyline Installation Guide for Ubuntu
=====================================

This section will guide you through the installation of Skyline
on Ubuntu 20.04 LTS.

.. toctree::
    :maxdepth: 2

    source-install-ubuntu
    docker-install-ubuntu
